summaryrefslogtreecommitdiff
path: root/examples/Misc/test_get_opt.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/Misc/test_get_opt.cpp')
-rw-r--r--examples/Misc/test_get_opt.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/Misc/test_get_opt.cpp b/examples/Misc/test_get_opt.cpp
index 3fd0a16ac80..dcb12e5eeff 100644
--- a/examples/Misc/test_get_opt.cpp
+++ b/examples/Misc/test_get_opt.cpp
@@ -1,6 +1,6 @@
// $Id$
// Test the ACE_Get_Opt class.
#include "ace/OS_main.h"
#include "ace/Get_Opt.h"
@@ -11,7 +11,7 @@ ACE_RCSID(Misc, test_get_opt, "$Id$")
int
ACE_TMAIN (int argc, ACE_TCHAR *argv[])
{
- ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("ab:cd:ef:gh:"));
+ ACE_Get_Arg_Opt<ACE_TCHAR> get_opt (argc, argv, ACE_TEXT("ab:cd:ef:gh:"));
int c;
while ((c = get_opt ()) != EOF)
@@ -1,6 +1,6 @@
// $Id$
-// Test the ACE_Get_Opt class.
+// Test the ACE_Get_Arg_Opt class.
#include "ace/OS_main.h"
#include "ace/Get_Opt.h"